% Auto-generated chapter 21 for malik
% Hadiths in this chapter: 50

\hadithdefcmd{malik}{959}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ كَمَثَلِ الصَّائِمِ الْقَائِمِ الدَّائِمِ الَّذِي لا يَفْتُرُ مِنْ صَلاَةٍ وَلاَ صِيَامٍ حَتَّى يَرْجِعَ ‏"‏ ‏.‏\hadithno{959}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said "Someone who does jihad in the way of Allah is like someone who fasts and prays constantly and who does not slacken from his prayer and fasting until he returns}}
\hadithdefcmd{malik}{960}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَكَفَّلَ اللَّهُ لِمَنْ جَاهَدَ فِي سَبِيلِهِ - لاَ يُخْرِجُهُ مِنْ بَيْتِهِ إِلاَّ الْجِهَادُ فِي سَبِيلِهِ وَتَصْدِيقُ كَلِمَاتِهِ - أَنْ يُدْخِلَهُ الْجَنَّةَ أَوْ يَرُدَّهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ مَعَ مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏\hadithno{960}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Allah guarantees either the Garden or a safe return to his home with whatever he has obtained of reward or booty, for the one who does jihad in His way, if it is solely jihad and trust in his promise that brings him out of his house}}
\hadithdefcmd{malik}{961}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِرَجُلٍ أَجْرٌ وَلِرَجُلٍ سِتْرٌ وَعَلَى رَجُلٍ وِزْرٌ فَأَمَّا الَّذِي هِيَ لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ فَأَطَالَ لَهَا فِي مَرْجٍ أَوْ رَوْضَةٍ فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ مِنَ الْمَرْجِ أَوِ الرَّوْضَةِ كَانَ لَهُ حَسَنَاتٌ وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا ذَلِكَ فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ آثَارُهَا وَأَرْوَاثُهَا حَسَنَاتٍ لَهُ وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ يَسْقِيَ بِهِ كَانَ ذَلِكَ لَهُ حَسَنَاتٍ فَهِيَ لَهُ أَجْرٌ وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَتَعَفُّفًا وَلَمْ يَنْسَ حَقَّ اللَّهِ فِي رِقَابِهَا وَلاَ فِي ظُهُورِهَا فَهِيَ لِذَلِكَ سِتْرٌ وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِيَاءً وَنِوَاءً لأَهْلِ الإِسْلاَمِ فَهِيَ عَلَى ذَلِكَ وِزْرٌ ‏"‏ ‏.‏ وَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحُمُرِ فَقَالَ ‏"‏ لَمْ يَنْزِلْ عَلَىَّ فِيهَا شَىْءٌ إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ ‏\}‏‏.‏\hadithno{961}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Horses are a reward for one man, a protection for another, a burden for another. The one who has them as a reward is the one who dedicates them for use in the way of Allah, and tethers them in a meadow or grassland. Whatever the horse enjoys of the grassland or meadow in the length of its tether are good deeds for him. If it breaks its tether and goes over a hillock or two, its tracks and droppings are good deeds for him. If it crosses a river and drinks from it while he did not mean to allow it to drink it, that counts as good deeds for him, and the horse is a reward for him. Another man uses his horse to gain self reliance and up- standingness and does not forget Allah's right on their necks and backs (i.e. he does not ill treat or over-work them). Horses are a protection for him . Another man uses them out of pride to show them off and in hostility to the people of Islam. They are a burden on that man." The Messenger of Allah, may Allah bless him and grant him peace, was asked about donkeys, and he said, "Nothing has been revealed to me about them except this single all- inclusive ayat, 'Whoever does an atom of good will see it, and whoever does an atom of evil, will see it.' " (Sura 99 Ayats)}}
\hadithdefcmd{malik}{962}{وَحَدَّثَنِي عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ الأَنْصَارِيِّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ النَّاسِ مَنْزِلاً رَجُلٌ آخِذٌ بِعِنَانِ فَرَسِهِ يُجَاهِدُ فِي سَبِيلِ اللَّهِ أَلاَ أُخْبِرُكُمْ بِخَيْرِ النَّاسِ مَنْزِلاً بَعْدَهُ رَجُلٌ مُعْتَزِلٌ فِي غُنَيْمَتِهِ يُقِيمُ الصَّلاَةَ وَيُؤْتِي الزَّكَاةَ وَيَعْبُدُ اللَّهَ لاَ يُشْرِكُ بِهِ شَيْئًا ‏"‏ ‏.‏\hadithno{962}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Abdullah ibn Abd ar-Rahman ibn Mamar al- Ansari that Ata ibn Yasar said that the Messenger of Allah, may Allah bless him and grant him peace, said, "Shall I tell you who has the best degree among people? A man who takes the rein of his horse to do jihad in the way of Allah. Shall I tell you who has the best degree among people after him? A man who lives alone with a few sheep, performs the prayer, pays the zakat, and worships Allah without associating anything with him}}
\hadithdefcmd{malik}{963}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عُبَادَةُ بْنُ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْيُسْرِ وَالْعُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَأَنْ نَقُولَ أَوْ نَقُومَ بِالْحَقِّ حَيْثُمَا كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{963}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, ''Ubada ibn al-Walid ibn Ubada ibn as-Samit informed me from his father that his grandfather (Ubada) said, 'We made a contract with the Messenger of Allah, may Allah bless him and grant him peace, to hear and obey in ease and hardship, enthusiasm and reluctance, and not to dispute with people in authority and to speak or establish the truth wherever we were without worrying about criticism}}
\hadithdefcmd{malik}{964}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، قَالَ كَتَبَ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ إِلَى عُمَرَ بْنِ الْخَطَّابِ يَذْكُرُ لَهُ جُمُوعًا مِنَ الرُّومِ وَمَا يَتَخَوَّفُ مِنْهُمْ فَكَتَبَ إِلَيْهِ عُمَرُ بْنُ الْخَطَّابِ أَمَّا بَعْدُ فَإِنَّهُ مَهْمَا يَنْزِلْ بِعَبْدٍ مُؤْمِنٍ مِنْ مُنْزَلِ شِدَّةٍ يَجْعَلِ اللَّهُ بَعْدَهُ فَرَجًا وَإِنَّهُ لَنْ يَغْلِبَ عُسْرٌ يُسْرَيْنِ وَأَنَّ اللَّهَ تَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا اصْبِرُوا وَصَابِرُوا وَرَابِطُوا وَاتَّقُوا اللَّهَ لَعَلَّكُمْ تُفْلِحُونَ ‏\}‏\hadithno{964}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Zayd ibn Aslam had said that Ubayda ibn al-Jarrah had written to Umar ibn al-Khattab mentioning to him a great array of Byzantine troops and the anxiety they were causing him. Umar ibn al-Khattab wrote in reply to him, "Whatever hardship befalls a believing slave, Allah will make an opening for him after it, and a hardship will not overcome two eases. Allah the Exalted says in His Book, 'O you who trust, be patient, and vie in patience; be steadfast and fear Allah, perhaps you will profit.' " (Sura 3 ayat)}}
\hadithdefcmd{malik}{965}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ ‏.‏\hadithno{965}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said that the Messenger of Allah, may Allah bless him and grant him peace, forbade travelling with a Qur'an in the land of the enemy. Malik commented, "That is out of fear that the enemy will get hold of it}}
\hadithdefcmd{malik}{966}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنٍ لِكَعْبِ بْنِ مَالِكٍ، - قَالَ حَسِبْتُ أَنَّهُ قَالَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبٍ، أَنَّهُ - قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الَّذِينَ قَتَلُوا ابْنَ أَبِي الْحُقَيْقِ عَنْ قَتْلِ النِّسَاءِ وَالْوِلْدَانِ - قَالَ - فَكَانَ رَجُلٌ مِنْهُمْ يَقُولُ بَرَّحَتْ بِنَا امْرَأَةُ ابْنِ أَبِي الْحُقَيْقِ بِالصِّيَاحِ فَأَرْفَعُ السَّيْفَ عَلَيْهَا ثُمَّ أَذْكُرُ نَهْىَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكُفُّ وَلَوْلاَ ذَلِكَ اسْتَرَحْنَا مِنْهَا ‏.‏\hadithno{966}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that a son of Kab ibn Malik (Malik believed that ibn Shihab said it was Abd ar-Rahman ibn Kab) said, "The Messenger of Allah, may Allah bless him and grant him peace, forbade those who fought ibn Abi Huqayq (a treacherous jew from Madina) to kill women and children. He said that one of the men fighting had said, 'The wife of ibn Abi Huqayq began screaming and I repeatedly raised my sword against her. Then I would remember the prohibition of the Messenger of Allah, may Allah bless him and grant him peace, so I would stop. Had it not been for that, we would have been rid of her}}
\hadithdefcmd{malik}{967}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى فِي بَعْضِ مَغَازِيهِ امْرَأَةً مَقْتُولَةً فَأَنْكَرَ ذَلِكَ وَنَهَى عَنْ قَتْلِ النِّسَاءِ وَالصِّبْيَانِ ‏.‏\hadithno{967}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, saw the corpse of a woman who had been slain in one of the raids, and he disapproved of it and forbade the killing of women and children}}
\hadithdefcmd{malik}{968}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، بَعَثَ جُيُوشًا إِلَى الشَّامِ فَخَرَجَ يَمْشِي مَعَ يَزِيدَ بْنِ أَبِي سُفْيَانَ - وَكَانَ أَمِيرَ رُبْعٍ مِنْ تِلْكَ الأَرْبَاعِ - فَزَعَمُوا أَنَّ يَزِيدَ قَالَ لأَبِي بَكْرٍ إِمَّا أَنْ تَرْكَبَ وَإِمَّا أَنْ أَنْزِلَ ‏.‏ فَقَالَ أَبُو بَكْرٍ مَا أَنْتَ بِنَازِلٍ وَمَا أَنَا بِرَاكِبٍ إِنِّي أَحْتَسِبُ خُطَاىَ هَذِهِ فِي سَبِيلِ اللَّهِ ثُمَّ قَالَ لَهُ إِنَّكَ سَتَجِدُ قَوْمًا زَعَمُوا أَنَّهُمْ حَبَّسُوا أَنْفُسَهُمْ لِلَّهِ فَذَرْهُمْ وَمَا زَعَمُوا أَنَّهُمْ حَبَّسُوا أَنْفُسَهُمْ لَهُ وَسَتَجِدُ قَوْمًا فَحَصُوا عَنْ أَوْسَاطِ رُءُوسِهِمْ مِنَ الشَّعَرِ فَاضْرِبْ مَا فَحَصُوا عَنْهُ بِالسَّيْفِ وَإِنِّي مُوصِيكَ بِعَشْرٍ لاَ تَقْتُلَنَّ امْرَأَةً وَلاَ صَبِيًّا وَلاَ كَبِيرًا هَرِمًا وَلاَ تَقْطَعَنَّ شَجَرًا مُثْمِرًا وَلاَ تُخَرِّبَنَّ عَامِرًا وَلاَ تَعْقِرَنَّ شَاةً وَلاَ بَعِيرًا إِلاَّ لِمَأْكُلَةٍ وَلاَ تَحْرِقَنَّ نَحْلاً وَلاَ تُفَرِّقَنَّهُ وَلاَ تَغْلُلْ وَلاَ تَجْبُنْ ‏.‏\hadithno{968}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abu Bakr as-Siddiq was sending armies to ash-Sham. He went for a walk with Yazid ibn Abi Sufyan who was the commander of one of the battalions. It is claimed that Yazid said to Abu Bakr, "Will you ride or shall I get down?" Abu Bakrsaid, "I will not ride and you will not get down. I intend these steps of mine to be in the way of Allah." Then Abu Bakr advised Yazid, "You will find a people who claim to have totally given themselves to Allah. Leave them to what they claim to have given themselves. You will find a people who have shaved the middle of their heads, strike what they have shaved with the sword. "I advise you ten things:Do not kill women or children or an aged, infirm person. Do not cut down fruit-bearing trees. Do not destroy an inhabited place. Do not slaughter sheep or camels except for food. Do not burn bees and do not scatter them. Do not steal from the booty, and do not be cowardly}}
\hadithdefcmd{malik}{969}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، كَتَبَ إِلَى عَامِلٍ مِنْ عُمَّالِهِ أَنَّهُ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا بَعَثَ سَرِيَّةً يَقُولُ لَهُمُ ‏ "‏ اغْزُوا بِاسْمِ اللَّهِ فِي سَبِيلِ اللَّهِ تُقَاتِلُونَ مَنْ كَفَرَ بِاللَّهِ لاَ تَغُلُّوا وَلاَ تَغْدِرُوا وَلاَ تُمَثِّلُوا وَلاَ تَقْتُلُوا وَلِيدًا وَقُلْ ذَلِكَ لِجِيُوشِكَ وَسَرَايَاكَ إِنْ شَاءَ اللَّهُ وَالسَّلاَمُ عَلَيْكَ ‏"‏ ‏.‏\hadithno{969}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn Abd al-Aziz wrote to one of his governors, "It has been passed down to us that when the Messenger of Allah, may Allah bless him and grant him peace, sent out a raiding party, he would say to them, 'Make your raids in the name of Allah in the way of Allah. Fight whoever denies Allah. Do not steal from the booty, and do not act treacherously. Do not mutilate and do not kill children.' Say the same to your armies and raiding parties, Allah willing. Peace be upon you}}
\hadithdefcmd{malik}{970}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْكُوفَةِ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَتَبَ إِلَى عَامِلِ جَيْشٍ كَانَ بَعَثَهُ إِنَّهُ بَلَغَنِي أَنَّ رِجَالاً مِنْكُمْ يَطْلُبُونَ الْعِلْجَ حَتَّى إِذَا أَسْنَدَ فِي الْجَبَلِ وَامْتَنَعَ قَالَ رَجُلٌ مَطْرَسْ - يَقُولَ لاَ تَخَفْ - فَإِذَا أَدْرَكَهُ قَتَلَهُ وَإِنِّي وَالَّذِي نَفْسِي بِيَدِهِ لاَ أَعْلَمُ مَكَانَ وَاحِدٍ فَعَلَ ذَلِكَ إِلاَّ ضَرَبْتُ عُنُقَهُ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ لَيْسَ هَذَا الْحَدِيثُ بِالْمُجْتَمَعِ عَلَيْهِ وَلَيْسَ عَلَيْهِ الْعَمَلُ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الإِشَارَةِ بِالأَمَانِ أَهِيَ بِمَنْزِلَةِ الْكَلاَمِ فَقَالَ نَعَمْ وَإِنِّي أَرَى أَنْ يُتَقَدَّمَ إِلَى الْجُيُوشِ أَنْ لاَ تَقْتُلُوا أَحَدًا أَشَارُوا إِلَيْهِ بِالأَمَانِ لأَنَّ الإِشَارَةَ عِنْدِي بِمَنْزِلَةِ الْكَلاَمِ وَإِنَّهُ بَلَغَنِي أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قَالَ مَا خَتَرَ قَوْمٌ بِالْعَهْدِ إِلاَّ سَلَّطَ اللَّهُ عَلَيْهِمُ الْعَدُوَّ ‏.‏\hadithno{970}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from a man of Kufa that Umar ibn al-Khattab wrote to a lieutenant of an army which he had sent out, "I have heard that it is the habit of some of your men to chase an unbeliever till he takes refuge in a high place. Then one man tells him in Persian not to be afraid, and when he comes up to him, he kills him. By He in whose hand my self is, if I knew someone who had done that, I would strike off his head." Yahya said, I heard Malik say, "This tradition is not unanimously agreed upon, so one does not act on it." Malik when asked whether safe conduct promised by gesture had the same status as that promised by speech, said, "Yes. I think that one can request an army not to kill someone by gesturing for safe conduct, because as far as I am concerned, gesture has the same status as speech. I have heard that Abdullah ibn Abbas said, 'There is no people who betray a pledge, but that Allah gives their enemies power over them}}
\hadithdefcmd{malik}{971}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا أَعْطَى شَيْئًا فِي سَبِيلِ اللَّهِ يَقُولُ لِصَاحِبِهِ إِذَا بَلَغْتَ وَادِيَ الْقُرَى فَشَأْنَكَ بِهِ ‏.‏\hadithno{971}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that when Abdullah ibn Umar gave something in the way of Allah, he would say to its owner, "When you reach Wadi'l-Qura, (on the outskirts of Madina) then it is your affair}}
\hadithdefcmd{malik}{972}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَقُولُ إِذَا أُعْطِيَ الرَّجُلُ الشَّىْءَ فِي الْغَزْوِ فَيَبْلُغُ بِهِ رَأْسَ مَغْزَاتِهِ فَهُوَ لَهُ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ أَوْجَبَ عَلَى نَفْسِهِ الْغَزْوَ فَتَجَهَّزَ حَتَّى إِذَا أَرَادَ أَنْ يَخْرُجَ مَنَعَهُ أَبَوَاهُ أَوْ أَحَدُهُمَا فَقَالَ لاَ يُكَابِرْهُمَا وَلَكِنْ يُؤَخِّرُ ذَلِكَ إِلَى عَامٍ آخَرَ فَأَمَّا الْجِهَازُ فَإِنِّي أَرَى أَنْ يَرْفَعَهُ حَتَّى يَخْرُجَ بِهِ فَإِنْ خَشِيَ أَنْ يَفْسُدَ بَاعَهُ وَأَمْسَكَ ثَمَنَهُ حَتَّى يَشْتَرِيَ بِهِ مَا يُصْلِحُهُ لِلْغَزْوِ فَإِنْ كَانَ مُوسِرًا يَجِدُ مِثْلَ جِهَازِهِ إِذَا خَرَجَ فَلْيَصْنَعْ بِجِهَازِهِ مَا شَاءَ ‏.‏\hadithno{972}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab used to say, "When a man is given something to use in a military expedition, and he brings it to the battlefield, it is his." Malik was asked about a man who pledged himself to go on a military campaign, equipped himself,and when he wanted to go out, one or both of his parents prevented him. He said, "He should not contradict them. Let him put it off for another year. As for the equipment, I think that he should store it until he needs it. If he fears that it will spoil, let him sell it and keep its price so that he can readily buy what is needed fora military expedition. If he is well-to-do, he will find the like of his equipment when he goes out, so let him do what he likes with his equipment}}
\hadithdefcmd{malik}{973}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ سَرِيَّةً فِيهَا عَبْدُ اللَّهِ بْنُ عُمَرَ قِبَلَ نَجْدٍ فَغَنِمُوا إِبِلاً كَثِيرَةً فَكَانَ سُهْمَانُهُمُ اثْنَىْ عَشَرَ بَعِيرًا أَوْ أَحَدَ عَشَرَ بَعِيرًا وَنُفِّلُوا بَعِيرًا بَعِيرًا ‏.‏\hadithno{973}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, sent a raiding party which included Abdullah ibn Umar near Najd. They plundered many camels and their portions were twelve or eleven camels each. They divided it up camel by camel}}
\hadithdefcmd{malik}{974}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ كَانَ النَّاسُ فِي الْغَزْوِ إِذَا اقْتَسَمُوا غَنَائِمَهُمْ يَعْدِلُونَ الْبَعِيرَ بِعَشْرِ شِيَاهٍ ‏.‏ قَالَ مَالِكٌ فِي الأَجِيرِ فِي الْغَزْوِ إِنَّهُ إِنْ كَانَ شَهِدَ الْقِتَالَ وَكَانَ مَعَ النَّاسِ عِنْدَ الْقِتَالِ وَكَانَ حُرًّا فَلَهُ سَهْمُهُ وَإِنْ لَمْ يَفْعَلْ ذَلِكَ فَلاَ سَهْمَ لَهُ وَأَرَى أَنْ لاَ يُقْسَمَ إِلاَّ لِمَنْ شَهِدَ الْقِتَالَ مِنَ الأَحْرَارِ ‏.‏\hadithno{974}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he heard Said ibn al-Musayyab say, "When people in military expeditions divided the spoils, they made a camel equal to ten sheep." Malik said about the paid labourer in military expeditions, "If he is present at the battle and is with the people in the battle and he is a free man, he has his share. If he is not present, he has no share." Malik summed up, "I think that the booty is only divided among free men who have been present at the battle}}
\hadithdefcmd{malik}{975}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدًا، لِعَبْدِ اللَّهِ بْنِ عُمَرَ أَبَقَ وَأَنَّ فَرَسًا لَهُ عَارَ فَأَصَابَهُمَا الْمُشْرِكُونَ ثُمَّ غَنِمَهُمَا الْمُسْلِمُونَ فَرُدَّا عَلَى عَبْدِ اللَّهِ بْنِ عُمَرَ وَذَلِكَ قَبْلَ أَنْ تُصِيبَهُمَا الْمَقَاسِمُ ‏.‏\hadithno{975}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said about enemy soldiers who were found on the seashore of a Muslim land, and they claimed that they were merchants and that the sea had driven them ashore, while the Muslims were not able to verify any of that except that their ships were damaged, or they were thirsty and had disembarked without the permission of the Muslims, "I think that it is up to the imam to give his opinion about them, and I do not think that the tax of one fifth is taken from them." Malik said, "I do not see that there is any harm in the Muslims eating whatever food they come across in enemy territory before the spoils are divided." Malik said, "I think that any camels, cattle and sheep (taken as booty) are considered as food which the Muslims can eat in enemy territory. If they could not be eaten until the people had gathered for the division and the spoils had been distributed among them, that would be harmful for the army. I do not see any objection to eating such things within acceptable limits. I do not think, however, that anyone should store up any of it to take back to his family." Malik was asked whether it was proper for a man who obtained food in enemy territory and ate some of it and made provision so that there was some of it left over to keep and eat with his family, or to sell before he had come to his country and make use of its price. He said, "If he sells it while he is on a military expedition, I think that he should put its price into the booty of the Muslims. If he takes it back to his country, I see no objection to his eating it and using it if it is a small insignificant thing." Yahya related to me from Malik that it reached him that a slave of Abdullah ibn Umar escaped and one of his horses wandered off, and the idol worshippers seized them. Then the Muslims recaptured them, and they were returned to Abdullah ibn Umar, before the division of the spoils took place. I heard Malik say about muslim property that had been seized by the enemy, "If it is noticed before the distribution, then it is returned to itsowner. Whatever has already been distributed is not returned to anyone." Malik, when asked about a man whose young male slave was taken by the idol worshippers and then the Muslims re-captured him, said, "The owner is more entitled to him without having to pay his price or value or having to incur any loss before the distribution takes place. If the distribution has already taken place then I think that the slave belongs to his master for his price if the master wants him back." Regarding an umm walad of a Muslim man who has been taken by the idol worshippers and then recaptured by the Muslims and allotted in the distribution of spoils and then recognised by her master after the distribution, Malik said, "She is not to be enslaved. I think that the Imam should pay a ransom for her for her master. If he does not do it, then her master must pay a ransom for her and not leave her. I do not think that she should be made a slave by whoever takes her and intercourse with her is not halal. She is in the position of a free woman because her master would be required to pay compensation if she injured somebody and so she is in the same position (as a wife). He must not leave the mother of his son to be enslaved nor may intercourse with her be made halal." Malik was asked about a man who went to enemy territory to pay ransom or to trade, and he bought a free man or a slave, or they were given to him. He said, "As for the free man, the price he buys him for is a debt against the man and he is not made a slave. If the captive is given to him freely, he is free and owes nothing unless the man gave something in recompense for him. That is a debt against the free man, the same as if a ransom had been paid for him. As for a slave, his former master can choose to take him back and pay his price to the man who bought him or he can choose to leave him, as he wishes. If he was given to the man, the former master is more entitled to him, and he owes nothing for him unless the man gave something for him in recompense. Whatever he gave for him is a loss against the master if he wants him back}}
\hadithdefcmd{malik}{976}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرِ بْنِ أَفْلَحَ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ بْنِ رِبْعِيٍّ، أَنَّهُ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حُنَيْنٍ فَلَمَّا الْتَقَيْنَا كَانَتْ لِلْمُسْلِمِينَ جَوْلَةٌ - قَالَ - فَرَأَيْتُ رَجُلاً مِنَ الْمُشْرِكِينَ قَدْ عَلاَ رَجُلاً مِنَ الْمُسْلِمِينَ - قَالَ - فَاسْتَدَرْتُ لَهُ حَتَّى أَتَيْتُهُ مِنْ وَرَائِهِ فَضَرَبْتُهُ بِالسَّيْفِ عَلَى حَبْلِ عَاتِقِهِ فَأَقْبَلَ عَلَىَّ فَضَمَّنِي ضَمَّةً وَجَدْتُ مِنْهَا رِيحَ الْمَوْتِ ثُمَّ أَدْرَكَهُ الْمَوْتُ فَأَرْسَلَنِي - قَالَ - فَلَقِيتُ عُمَرَ بْنَ الْخَطَّابِ فَقُلْتُ مَا بَالُ النَّاسِ فَقَالَ أَمْرُ اللَّهِ ‏.‏ ثُمَّ إِنَّ النَّاسَ رَجَعُوا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَتَلَ قَتِيلاً لَهُ عَلَيْهِ بَيِّنَةٌ فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ قَالَ فَقُمْتُ ثُمَّ قُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ قَتَلَ قَتِيلاً لَهُ عَلَيْهِ بَيِّنَةٌ فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ قَالَ فَقُمْتُ ثُمَّ قُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ثُمَّ قَالَ ذَلِكَ الثَّالِثَةَ فَقُمْتُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكَ يَا أَبَا قَتَادَةَ ‏"‏ ‏.‏ قَالَ فَاقْتَصَصْتُ عَلَيْهِ الْقِصَّةَ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ صَدَقَ يَا رَسُولَ اللَّهِ وَسَلَبُ ذَلِكَ الْقَتِيلِ عِنْدِي فَأَرْضِهِ عَنْهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ لاَ هَاءَ اللَّهِ إِذًا لاَ يَعْمِدُ إِلَى أَسَدٍ مِنْ أُسْدِ اللَّهِ يُقَاتِلُ عَنِ اللَّهِ وَرَسُولِهِ فَيُعْطِيكَ سَلَبَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَ فَأَعْطِهِ إِيَّاهُ ‏"‏ ‏.‏ فَأَعْطَانِيهِ فَبِعْتُ الدِّرْعَ فَاشْتَرَيْتُ بِهِ مَخْرَفًا فِي بَنِي سَلِمَةَ فَإِنَّهُ لأَوَّلُ مَالٍ تَأَثَّلْتُهُ فِي الإِسْلاَمِ ‏.‏\hadithno{976}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amr ibn Kathir ibn Aflah from Abu Muhammad, the mawla of Abu Qatada that Abu Qatada ibn Ribi said, "We went out with the Messenger of Allah, may Allah bless him and grant him peace, in the year of Hunayn. When the armies met, the Muslims were put in disarray. I saw a man from the idol worshippers who had got the better of one of the Muslims, so I circled round and came up behind him, and struck him with a sword on his shoulder-blade. He turned to me and grabbed me so hard that I felt the smell of death in it. Then death overcame him, and he let go of me." He continued, "I met Umar ibn al-Khattab and said to him, 'What's going on with the people?' He replied, 'The Command of Allah.' Then the people took hold of the battle and the Messenger of Allah, may Allah bless him and grant him peace, said, 'Whoever has killed one of the dead and can prove it, can strip him of his personal effects.' I stood up and said, 'Who will testify for me?' and then I sat down. The Messenger of Allah repeated, 'Whoever has killed one of the dead and can prove it, can strip him of his personal effects.' I stood up and said, 'Who will testify for me?' then I sat down. Then he repeated his statement a third time, so I stood up, and the Messenger of Allah, may Allah bless him and grant him peace, said, 'What's the matter with you, Abu Qatada?' So I related my story to him. A man said, 'He has spoken the truth, Messenger of Allah. I have the effects of that slain person with me, so give him compensation for it, Messenger of Allah.' Abu Bakr said, 'No, by Allah! He did not intend that one of the lions of Allah should fight for Allah and His Messenger and then give you his spoils.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'He has spoken the truth, hand it over to him.' He gave it to me, and I sold the breast-plate and I bought a garden in the area of the Banu Salima with the money. It was my first property, and I acquired it in Islam}}
\hadithdefcmd{malik}{977}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ قَالَ سَمِعْتُ رَجُلاً، يَسْأَلُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ عَنِ الأَنْفَالِ، فَقَالَ ابْنُ عَبَّاسٍ الْفَرَسُ مِنَ النَّفَلِ وَالسَّلَبُ مِنَ النَّفَلِ ‏.‏ قَالَ ثُمَّ عَادَ الرَّجُلُ لِمَسْأَلَتِهِ فَقَالَ ابْنُ عَبَّاسٍ ذَلِكَ أَيْضًا ثُمَّ قَالَ الرَّجُلُ الأَنْفَالُ الَّتِي قَالَ اللَّهُ فِي كِتَابِهِ مَا هِيَ قَالَ الْقَاسِمُ فَلَمْ يَزَلْ يَسْأَلُهُ حَتَّى كَادَ أَنْ يُحْرِجَهُ ثُمَّ قَالَ ابْنُ عَبَّاسٍ أَتَدْرُونَ مَا مَثَلُ هَذَا مَثَلُ صَبِيغٍ الَّذِي ضَرَبَهُ عُمَرُ بْنُ الْخَطَّابِ ‏.‏ قَالَ وَسُئِلَ مَالِكٌ عَمَّنْ قَتَلَ قَتِيلاً مِنَ الْعَدُوِّ أَيَكُونُ لَهُ سَلَبُهُ بِغَيْرِ إِذْنِ الإِمَامِ قَالَ لاَ يَكُونُ ذَلِكَ لأَحَدٍ بِغَيْرِ إِذْنِ الإِمَامِ وَلاَ يَكُونُ ذَلِكَ مِنَ الإِمَامِ إِلاَّ عَلَى وَجْهِ الاِجْتِهَادِ وَلَمْ يَبْلُغْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ قَتِيلاً فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ إِلاَّ يَوْمَ حُنَيْنٍ ‏.‏\hadithno{977}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that al-Qasim ibn Muhammad said that he had heard a man asking ibn Abbas about booty. Ibn Abbas said, "Horses are part of the booty and personal effects are as well." Then the man repeated his question, and Ibn Abbas repeated his answer. Then the man said, "What are the spoils which He, the Blessed, the Exalted, mentioned in His Book?" He kept on asking until Ibn Abbas was on the verge of being annoyed, then Ibn Abbas said, "Do you know who this man is like? Ibn Sabigh, who was beaten by Umar ibn al-Khattab because he was notorious for asking foolish questions." Yahya said that Malik was asked whether someone who killed one of the enemy could keep the man's effects without the permission of the Imam. He said, "No one can do that without the permission of the Imam. Only the Imam can make ijtihad. I have not heard that the Messenger of Allah, may Allah bless him and grant him peace, ever said, 'Whoever kills someone can have his effects,' on any other day than the day of Hunayn}}
\hadithdefcmd{malik}{978}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ كَانَ النَّاسُ يُعْطَوْنَ النَّفَلَ مِنَ الْخُمُسِ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ النَّفَلِ هَلْ يَكُونُ فِي أَوَّلِ مَغْنَمٍ قَالَ ذَلِكَ عَلَى وَجْهِ الاِجْتِهَادِ مِنَ الإِمَامِ وَلَيْسَ عِنْدَنَا فِي ذَلِكَ أَمْرٌ مَعْرُوفٌ مَوْثُوقٌ إِلاَّ اجْتِهَادُ السُّلْطَانِ وَلَمْ يَبْلُغْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَفَّلَ فِي مَغَازِيهِ كُلِّهَا وَقَدْ بَلَغَنِي أَنَّهُ نَفَّلَ فِي بَعْضِهَا يَوْمَ حُنَيْنٍ وَإِنَّمَا ذَلِكَ عَلَى وَجْهِ الاِجْتِهَادِ مِنَ الإِمَامِ فِي أَوَّلِ مَغْنَمٍ وَفِيمَا بَعْدَهُ ‏.‏\hadithno{978}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad that Said ibn al- Musayyab said, "People used to be given bonuses from the Khumus." Malik said, "That is the best of what I have heard on the matter." Malik was asked about bonuses and whether they were taken from the first of the spoils, and he said, "That is only decided according to the ijtihad of the Imam. We do not have a known reliable command about that other than it is up to the ijtihad of the Sultan. I have not heard that the Messenger of Allah, may Allah bless him and grant him peace, gave bonuses in all his raids. I have only heard that he gave bonuses in one of them, namely the day of Hunayn. It depends on the ijtihad of the Imam whether they are taken from the first of the spoils or what is after it}}
\hadithdefcmd{malik}{979}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، كَانَ يَقُولُ لِلْفَرَسِ سَهْمَانِ وَلِلرَّجُلِ سَهْمٌ ‏.‏ قَالَ مَالِكٌ وَلَمْ أَزَلْ أَسْمَعُ ذَلِكَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ يَحْضُرُ بِأَفْرَاسٍ كَثِيرَةٍ فَهَلْ يُقْسَمُ لَهَا كُلِّهَا فَقَالَ لَمْ أَسْمَعْ بِذَلِكَ وَلاَ أَرَى أَنْ يُقْسَمَ إِلاَّ لِفَرَسٍ وَاحِدٍ الَّذِي يُقَاتِلُ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ لاَ أَرَى الْبَرَاذِينَ وَالْهُجُنَ إِلاَّ مِنَ الْخَيْلِ لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏وَالْخَيْلَ وَالْبِغَالَ وَالْحَمِيرَ لِتَرْكَبُوهَا وَزِينَةً‏\}‏ وَقَالَ عَزَّ وَجَلَّ ‏\{‏وَأَعِدُّوا لَهُمْ مَا اسْتَطَعْتُمْ مِنْ قُوَّةٍ وَمِنْ رِبَاطِ الْخَيْلِ تُرْهِبُونَ بِهِ عَدُوَّ اللَّهِ وَعَدُوَّكُمْ‏\}‏ فَأَنَا أَرَى الْبَرَاذِينَ وَالْهُجُنَ مِنَ الْخَيْلِ إِذَا أَجَازَهَا الْوَالِي وَقَدْ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ وَسُئِلَ عَنِ الْبَرَاذِينَ هَلْ فِيهَا مِنْ صَدَقَةٍ فَقَالَ وَهَلْ فِي الْخَيْلِ مِنْ صَدَقَةٍ\hadithno{979}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me that Malik said that he had heard that Umar ibn Abd al-Aziz used to say, "The man on horse-back has two shares, and the man on foot has one." Malik added, "I continue to hear the same." Malik, when asked whether a man who was present with several horses took a share for all of them, said, "I have never heard that. I think that there is only a share for the horse on which he fought." Malik said, "I think that foreign horses and half-breeds are considered as horses because Allah, the Blessed, the Exalted, said in His Book, 'All horses, and mules, and asses, for you to ride, and as an adornment.' (Sura16 ayat 8). He said, the Mighty, the Majestic, 'Make ready for them whatever force and strings of horses you can, to terrify thereby the enemy of Allah and your enemy.' (Sura 8 ayat 60). I think that foreign breeds and half-breeds are considered as horses if the governor accepts them." Said ibn al-Musayyab was asked about working horses, and whether there was zakat on them. He said, "Is there any zakat on horses.?}}
\hadithdefcmd{malik}{980}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ صَدَرَ مِنْ حُنَيْنٍ وَهُوَ يُرِيدُ الْجِعِرَّانَةَ سَأَلَهُ النَّاسُ حَتَّى دَنَتْ بِهِ نَاقَتُهُ مِنْ شَجَرَةٍ فَتَشَبَّكَتْ بِرِدَائِهِ حَتَّى نَزَعَتْهُ عَنْ ظَهْرِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رُدُّوا عَلَىَّ رِدَائِي أَتَخَافُونَ أَنْ لاَ أَقْسِمَ بَيْنَكُمْ مَا أَفَاءَ اللَّهُ عَلَيْكُمْ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَفَاءَ اللَّهُ عَلَيْكُمْ مِثْلَ سَمُرِ تِهَامَةَ نَعَمًا لَقَسَمْتُهُ بَيْنَكُمْ ثُمَّ لاَ تَجِدُونِي بَخِيلاً وَلاَ جَبَانًا وَلاَ كَذَّابًا ‏"‏ ‏.‏ فَلَمَّا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ فِي النَّاسِ فَقَالَ ‏"‏ أَدُّوا الْخِيَاطَ وَالْمِخْيَطَ فَإِنَّ الْغُلُولَ عَارٌ وَنَارٌ وَشَنَارٌ عَلَى أَهْلِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ ثُمَّ تَنَاوَلَ مِنَ الأَرْضِ وَبَرَةً مِنْ بَعِيرٍ أَوْ شَيْئًا ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا لِي مِمَّا أَفَاءَ اللَّهُ عَلَيْكُمْ وَلاَ مِثْلَ هَذِهِ إِلاَّ الْخُمُسُ وَالْخُمُسُ مَرْدُودٌ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{980}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn Said from Amr ibn Shuayb that when the Messenger of Allah, may Allah bless him and grant him peace, came back from Hunayn heading for al-Jiirrana, the people crowded around so much to question him that his she-camel backed into a tree, which became entangled in his cloak and pulled it off his back. The Messenger of Allah, may Allah bless him and grant him peace, said, "Return my cloak to me. Are you afraid that I will not distribute among you what Allah has given you as spoils. By He in whose hand my self is! Had Allah given you spoils equal to the number of acacia trees on the plain of Tihama, I would have distributed it among you. You will not find me to be miserly, cowardly, or a liar." Then the Messenger of Allah, may Allah bless him and grant him peace, got down and stood among the people, and said, "Hand over even the needle and thread, for stealing from the spoils is disgrace, fire, ignominy on the Day of Rising for people who do it." Then he took a bit of camel fluff or something from the ground and said, "By He in whose hand my self is! What Allah has made spoils for you is not mine - even the like of this! - except for the tax of one fifth, and the tax of one fifth is returned to you}}
\hadithdefcmd{malik}{981}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، قَالَ تُوُفِّيَ رَجُلٌ يَوْمَ حُنَيْنٍ وَإِنَّهُمْ ذَكَرُوهُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَزَعَمَ زَيْدٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَتَغَيَّرَتْ وُجُوهُ النَّاسِ لِذَلِكَ فَزَعَمَ زَيْدٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ صَاحِبَكُمْ قَدْ غَلَّ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ فَفَتَحْنَا مَتَاعَهُ فَوَجَدْنَا خَرَزَاتٍ مِنْ خَرَزِ يَهُودَ مَا تُسَاوِينَ دِرْهَمَيْنِ ‏.‏\hadithno{981}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Yahya ibn Habban from Ibn Abi Amra that Zayd ibn Khalid al-Juhani said, "A man died on the day of Hunayn, and they mentioned him to the Messenger of Allah, may Allah bless him and grant him peace." Zayd claimed that the Messenger of Allah, may Allah bless him and grant him peace, said, "You pray over your companion." (i.e. he would not pray himself). The people's faces dropped at that. Zayd claimed that the Messenger of Allah, may Allah bless him and grant him peace, said, "Your companion stole from the spoils taken in the way of Allah." Zayd said, "So we opened up his baggage and found some Jews' beads worth about two dirhams}}
\hadithdefcmd{malik}{982}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُغِيرَةِ بْنِ أَبِي بُرْدَةَ الْكِنَانِيِّ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى النَّاسَ فِي قَبَائِلِهِمْ يَدْعُو لَهُمْ وَأَنَّهُ تَرَكَ قَبِيلَةً مِنَ الْقَبَائِلِ - قَالَ - وَإِنَّ الْقَبِيلَةَ وَجَدُوا فِي بَرْدَعَةِ رَجُلٍ مِنْهُمْ عِقْدَ جَزْعٍ غُلُولاً فَأَتَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ عَلَيْهِمْ كَمَا يُكَبِّرُ عَلَى الْمَيِّتِ ‏.‏\hadithno{982}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abdullah ibn al-Mughira ibn Abi Burda al-Kinani that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, came to the people in their tribes and made dua for them, but left out one of the tribes. Abdullah related, "The tribe found an onyx necklace in the saddle-bags of one of their men. The Messenger of Allah, may Allah bless him and grant him peace, came to them, and then did the takbir over them as one does the takbir over the dead}}
\hadithdefcmd{malik}{983}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، سَالِمٍ مَوْلَى ابْنِ مُطِيعٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حُنَيْنٍ فَلَمْ نَغْنَمْ ذَهَبًا وَلاَ وَرِقًا إِلاَّ الأَمْوَالَ الثِّيَابَ وَالْمَتَاعَ - قَالَ - فَأَهْدَى رِفَاعَةُ بْنُ زَيْدٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُلاَمًا أَسْوَدَ يُقَالُ لَهُ مِدْعَمٌ فَوَجَّهَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى وَادِي الْقُرَى حَتَّى إِذَا كُنَّا بِوَادِي الْقُرَى بَيْنَمَا مِدْعَمٌ يَحُطُّ رَحْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ سَهْمٌ عَائِرٌ فَأَصَابَهُ فَقَتَلَهُ فَقَالَ النَّاسُ هَنِيئًا لَهُ الْجَنَّةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَلاَّ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ الشَّمْلَةَ الَّتِي أَخَذَ يَوْمَ حُنَيْنٍ مِنَ الْمَغَانِمِ لَمْ تُصِبْهَا الْمَقَاسِمُ لَتَشْتَعِلُ عَلَيْهِ نَارًا ‏"‏ ‏.‏ قَالَ فَلَمَّا سَمِعَ النَّاسُ ذَلِكَ جَاءَ رَجُلٌ بِشِرَاكٍ أَوْ شِرَاكَيْنِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شِرَاكٌ أَوْ شِرَاكَانِ مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{983}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili from Abu'l-Ghayth Salim, the mawla of ibn Muti that Abu Hurayra said, "We went out with the Messenger of Allah, may Allah bless him and grant him peace, in the yearof Khaybar. We did not capture any gold or silver except for personal effects, clothes, and baggage. Rifaa ibn Zayd presented a black slave boy to the Messenger of Allah, may Allah bless him and grant him peace, whose name was Midam. The Messenger of Allah, may Allah bless him and grant him peace, made for Wadi'l-Qura, and when he arrived there, Midam was unsaddling the camel of the Messenger of Allah, may Allah bless him and grant him peace, when a stray arrow struck and killed him. The people said, 'Good luck to him! The Garden!' The Messenger of Allah said, 'No! By He in whose hand my self is! The cloak which he took from the spoils on the Day of Khaybar before they were distributed will blaze with fire on him.' When the people heard that, a man brought a sandal-strap or two sandal-straps to the Messenger of Allah, may Allah bless him and grant him peace. The Messenger of Allah, may Allah bless him and grant him peace, said, 'A sandal-strap or two sandal-straps of fire}}
\hadithdefcmd{malik}{984}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ مَا ظَهَرَ الْغُلُولُ فِي قَوْمٍ قَطُّ إِلاَّ أُلْقِيَ فِي قُلُوبِهِمُ الرُّعْبُ وَلاَ فَشَا الزِّنَا فِي قَوْمٍ قَطُّ إِلاَّ كَثُرَ فِيهِمُ الْمَوْتُ وَلاَ نَقَصَ قَوْمٌ الْمِكْيَالَ وَالْمِيزَانَ إِلاَّ قُطِعَ عَنْهُمُ الرِّزْقُ وَلاَ حَكَمَ قَوْمٌ بِغَيْرِ الْحَقِّ إِلاَّ فَشَا فِيهِمُ الدَّمُ وَلاَ خَتَرَ قَوْمٌ بِالْعَهْدِ إِلاَّ سَلَّطَ اللَّهُ عَلَيْهِمُ الْعَدُوَّ ‏.‏\hadithno{984}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he had heard that Abdullah ibn Abbas said, "Stealing from the spoils does not appear in a people but that terror is cast into their hearts. Fornication does not spread in a people but that there is much death among them. A people do not lessen the measure and weight but that provision is cut off from them. A people do not judge without right but that blood spreads among them. A people do not betray the pledge but that Allah gives their enemies power over them}}
\hadithdefcmd{malik}{985}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوَدِدْتُ أَنِّي أُقَاتِلُ فِي سَبِيلِ اللَّهِ فَأُقْتَلُ ثُمَّ أُحْيَا فَأُقْتَلُ ثُمَّ أُحْيَا فَأُقْتَلُ ‏"‏ ‏.‏ فَكَانَ أَبُو هُرَيْرَةَ يَقُولُ ثَلاَثًا أَشْهَدُ بِاللَّهِ ‏.‏\hadithno{985}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "By He in whose hand my self is! I would like to fight in the way of Allah and be killed, then be brought to life again so I could be killed, and then be brought to life again so I could be killed." Abu Hurayra said three times, "I testify to it by Allah}}
\hadithdefcmd{malik}{986}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَضْحَكُ اللَّهُ إِلَى رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ كِلاَهُمَا يَدْخُلُ الْجَنَّةَ يُقَاتِلُ هَذَا فِي سَبِيلِ اللَّهِ فَيُقْتَلُ ثُمَّ يَتُوبُ اللَّهُ عَلَى الْقَاتِلِ فَيُقَاتِلُ فَيُسْتَشْهَدُ ‏"‏ ‏.‏\hadithno{986}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Allah laughs at two men. One of them kills the other, but each of them will enter the Garden:one fights in the way of Allah and is killed, then Allah turns to the killer, so he fights (in the way of Allah) and also becomes a martyr}}
\hadithdefcmd{malik}{987}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يُكْلَمُ أَحَدٌ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُكْلَمُ فِي سَبِيلِهِ - إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَجُرْحُهُ يَثْعَبُ دَمًا اللَّوْنُ لَوْنُ دَمٍ وَالرِّيحُ رِيحُ الْمِسْكِ ‏"‏ ‏.‏\hadithno{987}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "By He in whose hand my self is! None of you is wounded in the way of Allah - and Allah knows best who is wounded in HisWay, but that when the Day of Rising comes, blood will gush forth from his wound. It will be the colour of blood, but its scent will be that of musk}}
\hadithdefcmd{malik}{988}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَقُولُ اللَّهُمَّ لاَ تَجْعَلْ قَتْلِي بِيَدِ رَجُلٍ صَلَّى لَكَ سَجْدَةً وَاحِدَةً يُحَاجُّنِي بِهَا عِنْدَكَ يَوْمَ الْقِيَامَةِ ‏.‏\hadithno{988}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Umar ibn al-Khattab used to say, "O Allah! Do not let me be slain by the hand of a man who has prayed a single prostration to You with which he will dispute with me before You on the Day of Rising}}
\hadithdefcmd{malik}{989}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ صَابِرًا مُحْتَسِبًا مُقْبِلاً غَيْرَ مُدْبِرٍ أَيُكَفِّرُ اللَّهُ عَنِّي خَطَايَاىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرَ الرَّجُلُ نَادَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ بِهِ فَنُودِيَ لَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ فَأَعَادَ عَلَيْهِ قَوْلَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ إِلاَّ الدَّيْنَ كَذَلِكَ قَالَ لِي جِبْرِيلُ ‏"‏ ‏.‏\hadithno{989}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said al- Maqburi from Abdullah ibn Abi Qatada that his father had said that a man came to the Messenger of Allah, may Allah bless him and grant him peace, and said, "O Messenger of Allah! If I am killed in the way of Allah, expectant for reward, sincere, advancing, and not retreating, will Allah pardon my faults?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes." When the man turned away, the Messenger of Allah, may Allah bless him and grant him peace, called him - or commanded him and he was called to him. The Messenger of Allah, may Allah bless him and grant him peace, said to him, "What did you say?" He repeated his words to him, and the Prophet, may Allah bless him and grant him peace, said to him, "Yes, except for the debt. Jibril said that to me}}
\hadithdefcmd{malik}{990}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِشُهَدَاءِ أُحُدٍ ‏"‏ هَؤُلاَءِ أَشْهَدُ عَلَيْهِمْ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ الصِّدِّيقُ أَلَسْنَا يَا رَسُولَ اللَّهِ بِإِخْوَانِهِمْ أَسْلَمْنَا كَمَا أَسْلَمُوا وَجَاهَدْنَا كَمَا جَاهَدُوا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَلَى وَلَكِنْ لاَ أَدْرِي مَا تُحْدِثُونَ بَعْدِي ‏"‏ ‏.‏ فَبَكَى أَبُو بَكْرٍ ثُمَّ بَكَى ثُمَّ قَالَ أَئِنَّا لَكَائِنُونَ بَعْدَكَ\hadithno{990}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said over the martyrs of Uhud, "I testify for them." Abu Bakr as-Siddiq said, "Messenger of Allah! Are we not their brothers? We entered Islam as they entered Islam and we did jihad as they did jihad." The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes, but I do not know what you will do after me." Abu Bakr wept profusely and said, "Are we really going to out-live you}}
\hadithdefcmd{malik}{991}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا وَقَبْرٌ يُحْفَرُ بِالْمَدِينَةِ فَاطَّلَعَ رَجُلٌ فِي الْقَبْرِ فَقَالَ بِئْسَ مَضْجَعُ الْمُؤْمِنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِئْسَ مَا قُلْتَ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي لَمْ أُرِدْ هَذَا يَا رَسُولَ اللَّهِ إِنَّمَا أَرَدْتُ الْقَتْلَ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ مِثْلَ لِلْقَتْلِ فِي سَبِيلِ اللَّهِ مَا عَلَى الأَرْضِ بُقْعَةٌ هِيَ أَحَبُّ إِلَىَّ أَنْ يَكُونَ قَبْرِي بِهَا مِنْهَا ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ يَعْنِي الْمَدِينَةَ ‏.‏\hadithno{991}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "The Messenger of Allah, may Allah bless him and grant him peace, was sitting by a grave which was being dug at Madina. A man looked into the grave and said, 'An awful bed for the mumin. 'The Messenger of Allah, may Allah blesshim and grant him peace, said, 'Evil? What you have said is absolutely wrong.' The man said, 'I didn't mean that, Messenger of Allah. I meant being killed in the way of Allah.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Being killed in the way of Allah has no like! There is no place on the earth which I would prefer my grave to be than here (meaning Madina). He repeated it three times}}
\hadithdefcmd{malik}{992}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ شَهَادَةً فِي سَبِيلِكَ وَوَفَاةً بِبَلَدِ رَسُولِكَ ‏.‏\hadithno{992}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Umar ibn al-Khattab used to say, "O Allah! I ask you for martyrdom in Your way and death in the city of Your Messenger}}
\hadithdefcmd{malik}{993}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ كَرَمُ الْمُؤْمِنِ تَقْوَاهُ وَدِينُهُ حَسَبُهُ وَمُرُوءَتُهُ خُلُقُهُ وَالْجُرْأَةُ وَالْجُبْنُ غَرَائِزُ يَضَعُهَا اللَّهُ حَيْثُ شَاءَ فَالْجَبَانُ يَفِرُّ عَنْ أَبِيهِ وَأُمِّهِ وَالْجَرِيءُ يُقَاتِلُ عَمَّا لاَ يَؤُوبُ بِهِ إِلَى رَحْلِهِ وَالْقَتْلُ حَتْفٌ مِنَ الْحُتُوفِ وَالشَّهِيدُ مَنِ احْتَسَبَ نَفْسَهُ عَلَى اللَّهِ ‏.‏\hadithno{993}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Umar ibn al-Khattab said, "The nobility of the mumin is his taqwa. His deen is his noble descent. His manliness is his good character. Boldness and cowardice are but instincts which Allah places wherever He wills. The coward shrinks from defending even his father and mother, and the bold one fights for the sake of the combat not for the spoils. Being slain is but one way of meeting death, and the martyr is the one who gives himself, expectant of reward from Allah}}
\hadithdefcmd{malik}{994}{\hadithno{994}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{995}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَحْمِلُ فِي الْعَامِ الْوَاحِدِ عَلَى أَرْبَعِينَ أَلْفِ بَعِيرٍ يَحْمِلُ الرَّجُلَ إِلَى الشَّامِ عَلَى بَعِيرٍ وَيَحْمِلُ الرَّجُلَيْنِ إِلَى الْعِرَاقِ عَلَى بَعِيرٍ فَجَاءَهُ رَجُلٌ مِنْ أَهْلِ الْعِرَاقِ فَقَالَ احْمِلْنِي وَسُحَيْمًا ‏.‏ فَقَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ نَشَدْتُكَ اللَّهَ أَسُحَيْمٌ زِقٌّ قَالَ لَهُ نَعَمْ ‏.‏\hadithno{995}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
\hadithdefcmd{malik}{996}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ إِلَى قُبَاءٍ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ وَكَانَتْ أُمُّ حَرَامٍ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَأَطْعَمَتْهُ وَجَلَسَتْ تَفْلِي فِي رَأْسِهِ فَنَامَ رَسُولُ اللَّهِ صلى الله عليه\hadithno{996}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik had said that when the Messenger of Allah, may Allah bless him and grant him peace, went to Quba, he visited Umm Haram bint Milhan and she fed him. Umm Haram was the wife of Ubada ibn as-Samit. One day the Messenger of Allah, may Allah bless him and grant him peace, had called on her and she had fed him, and sat down to delouse his hair. The Messenger of Allah, may Allah bless him and grant him peace, had dozed and woke up smiling. Umm Haram said, "What is making you smile, Messenger of Allah?" He said, "Some of my community were presented to me, raiding in the way of Allah. They were riding in the middle of the sea, kings on thrones, or like kings on thrones." (Ishaq wasn't sure). She said, "O Messenger of Allah! Ask Allah to put me among them!" So he had made a dua for her, and put his head down and slept. Then he had woken up smiling, and she said to him, "Messenger of Allah, why are you smiling?" He said, "Some of my community were presented to me, raiding in the way of Allah. They were kings on thrones or like kings on thrones," as he had said in the first one. She said, "O Messenger of Allah! Ask Allah to put me among them!" He said, "You are among the first." Ishaq added, "She travelled on the sea in the time of Muawiya, and when she landed, she was thrown from her mount and killed}}
\hadithdefcmd{malik}{997}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَحْبَبْتُ أَنْ لاَ أَتَخَلَّفَ عَنْ سَرِيَّةٍ تَخْرُجُ فِي سَبِيلِ اللَّهِ وَلَكِنِّي لاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ وَلاَ يَجِدُونَ مَا يَتَحَمَّلُونَ عَلَيْهِ فَيَخْرُجُونَ وَيَشُقُّ عَلَيْهِمْ أَنْ يَتَخَلَّفُوا بَعْدِي فَوَدِدْتُ أَنِّي أُقَاتِلُ فِي سَبِيلِ اللَّهِ فَأُقْتَلُ ثُمَّ أُحْيَا فَأُقْتَلُ ثُمَّ أُحْيَا فَأُقْتَلُ ‏"‏ ‏.‏\hadithno{997}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Had I not been concerned for my community, I would have liked never to stay behind a raiding party going out in the way of Allah. However, I do not find the means to carry them to it, nor do they find anything on which to ride out and it is grievous for them that they should stay behind me. I would like to fight in the way of Allah and be killed, then brought to life so I could be killed and then brought to life so I could be killed}}
\hadithdefcmd{malik}{998}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَأْتِينِي بِخَبَرِ سَعْدِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ فَذَهَبَ الرَّجُلُ يَطُوفُ بَيْنَ الْقَتْلَى فَقَالَ لَهُ سَعْدُ بْنُ الرَّبِيعِ مَا شَأْنُكَ فَقَالَ لَهُ الرَّجُلُ بَعَثَنِي إِلَيْكَ رَسُولُ اللَّهِ صلى الله عليه وسلم لآتِيَهُ بِخَبَرِكَ ‏.‏ قَالَ فَاذْهَبْ إِلَيْهِ فَأَقْرِئْهُ مِنِّي السَّلاَمَ وَأَخْبِرْهُ أَنِّي قَدْ طُعِنْتُ اثْنَتَىْ عَشْرَةَ طَعْنَةً وَأَنِّي قَدْ أُنْفِذَتْ مَقَاتِلِي وَأَخْبِرْ قَوْمَكَ أَنَّهُ لاَ عُذْرَ لَهُمْ عِنْدَ اللَّهِ إِنْ قُتِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَوَاحِدٌ مِنْهُمْ حَىٌّ ‏.‏\hadithno{998}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "On the Day of Uhud, The Messenger of Allah, may Allah bless him and grant him peace, said, 'Who will bring me news of Sad ibn al-Rabi al-Ansari?' a man said, 'Me, Messenger of Allah!' So the man went around among the slain, and Sad ibn al-Rabi said to him, 'What are you doing?' The man said to him, 'The Messenger of Allah, may Allah bless him and grant him peace, sent me to bring him news of you.' He said, 'Go to him, and give him my greetings, and tell him that I have been stabbed twelve times, and am mortally wounded. Tell your people that they will have no excuse with Allah if the Messenger of Allah, may Allah bless him and grant him peace, is slain while one of them is still alive}}
\hadithdefcmd{malik}{999}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَغَّبَ فِي الْجِهَادِ وَذَكَرَ الْجَنَّةَ وَرَجُلٌ مِنَ الأَنْصَارِ يَأْكُلُ تَمَرَاتٍ فِي يَدِهِ فَقَالَ إِنِّي لَحَرِيصُ عَلَى الدُّنْيَا إِنْ جَلَسْتُ حَتَّى أَفْرُغَ مِنْهُنَّ ‏.‏ فَرَمَى مَا فِي يَدِهِ فَحَمَلَ بِسَيْفِهِ فَقَاتَلَ حَتَّى قُتِلَ ‏.‏\hadithno{999}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that the Messenger of Allah, may Allah bless him and grant him peace, stimulated people for jihad and mentioned the Garden. One of the Ansar was eating some dates in his hand, and said, "Am I so desirous of this world that I should sit until I finish them?" He threw aside what was in his hand and took his sword, and fought until he was slain}}
\hadithdefcmd{malik}{1000}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّهُ قَالَ الْغَزْوُ غَزْوَانِ فَغَزْوٌ تُنْفَقُ فِيهِ الْكَرِيمَةُ وَيُيَاسَرُ فِيهِ الشَّرِيكُ وَيُطَاعُ فِيهِ ذُو الأَمْرِ وَيُجْتَنَبُ فِيهِ الْفَسَادُ فَذَلِكَ الْغَزْوُ خَيْرٌ كُلُّهُ وَغَزْوٌ لاَ تُنْفَقُ فِيهِ الْكَرِيمَةُ وَلاَ يُيَاسَرُ فِيهِ الشَّرِيكُ وَلاَ يُطَاعُ فِيهِ ذُو الأَمْرِ وَلاَ يُجْتَنَبُ فِيهِ الْفَسَادُ فَذَلِكَ الْغَزْوُ لاَ يَرْجِعُ صَاحِبُهُ كَفَافًا ‏.‏\hadithno{1000}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Muadh ibn Jabal said, "There are two military expeditions. There is one military expedition in which valuables are spent, the contributor is willing, the authorities are obeyed, and corruption is avoided. That military expedition is all good. There is a military expedition in which valuables are not spent, the contributor is not willing, the authorities are not obeyed, and corruption is not avoided. The one who fights in that military expedition does not return with reward}}
\hadithdefcmd{malik}{1001}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1001}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Blessing is in the forelocks of horses until the Day of Rising}}
\hadithdefcmd{malik}{1002}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَابَقَ بَيْنَ الْخَيْلِ الَّتِي قَدْ أُضْمِرَتْ مِنَ الْحَفْيَاءِ وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضَمَّرْ مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ وَأَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ كَانَ مِمَّنْ سَابَقَ بِهَا ‏.‏\hadithno{1002}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, held a race between horses which had been made lean by training, from al-Hafya to Thaniyatu-lWada. He held a race between horses which had not been made lean from the Thaniya (a mountain pass near Madina) to the mosque of the Banu Zurayq. Abdullah ibn Umar was among those who raced them}}
\hadithdefcmd{malik}{1003}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ لَيْسَ بِرِهَانِ الْخَيْلِ بَأْسٌ إِذَا دَخَلَ فِيهَا مُحَلِّلٌ فَإِنْ سَبَقَ أَخَذَ السَّبَقَ وَإِنْ سُبِقَ لَمْ يَكُنْ عَلَيْهِ شَىْءٌ ‏.‏\hadithno{1003}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard Said ibn al-Musayyab say, "There is no harm in placing stakes on horses if a third horse enters it. The winner takes the stake, and there is no fine against the loser}}
\hadithdefcmd{malik}{1004}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رُئِيَ وَهُوَ يَمْسَحُ وَجْهَ فَرَسِهِ بِرِدَائِهِ فَسُئِلَ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنِّي عُوتِبْتُ اللَّيْلَةَ فِي الْخَيْلِ ‏"‏ ‏.‏\hadithno{1004}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that the Messenger of Allah, may Allah bless him and grant him peace, was seen wiping the face of his horse with his cloak. He was questioned about it and said, "I was reproached in the night about horses." i.e. not taking care of them}}
\hadithdefcmd{malik}{1005}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ خَرَجَ إِلَى خَيْبَرَ أَتَاهَا لَيْلاً وَكَانَ إِذَا أَتَى قَوْمًا بِلَيْلٍ لَمْ يُغِرْ حَتَّى يُصْبِحَ فَخَرَجَتْ يَهُودُ بِمَسَاحِيهِمْ وَمَكَاتِلِهِمْ فَلَمَّا رَأَوْهُ قَالُوا مُحَمَّدٌ وَاللَّهِ مُحَمَّدٌ وَالْخَمِيسُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏\hadithno{1005}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Humayd at-Tawil from Anas ibn Malik that when the Messenger of Allah, may Allah bless him and grant him peace, went out to Khaybar, he arrived there at night, and when he came upon a people by night, he did not attack until morning. In the morning, the jews came out with their spades and baskets. When they saw him, they said, "Muhammad! By Allah, Muhammad and his army!" The Messenger of Allah, may Allah bless him and grant him peace, said "Allah is greater! Khaybar is destroyed. When we come to a people, it is an evil morning for those who have been warned}}
\hadithdefcmd{malik}{1006}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ الصِّدِّيقُ يَا رَسُولَ اللَّهِ مَا عَلَى مَنْ يُدْعَى مِنْ هَذِهِ الأَبْوَابِ مِنْ ضَرُورَةٍ فَهَلْ يُدْعَى أَحَدٌ مِنْ هَذِهِ الأَبْوَابِ كُلِّهَا قَالَ ‏"‏ نَعَمْ وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{1006}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Humayd ibn Abd ar-Rahman ibn Awf from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever hands over two of any type of property in the way of Allah is called to the Garden, with the words 'O slave of Allah! This is good!' Whoever is among the people of prayer, is called from the gate of prayer. Whoever is among the people of jihad is called from the gate of jihad. Whoever is among the people of sadaqa, is called from the gate of sadaqa. Whoever is among the people of fasting, is called from the gate of the well- watered. (Bab ar-Rayyan)." Abu Bakr as-Siddiq said, "Messenger of Allah! Is it absolutely necessary that one be called from one of these gates? Can someone be called from all of these gates?" He said, "Yes, and I hope you are among them ." 21.20 Acquisition of the Land of Those who Surrender from the People of Dhimma}}
\hadithdefcmd{malik}{1007}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، أَنَّهُ بَلَغَهُ أَنَّ عَمْرَو بْنَ الْجَمُوحِ، وَعَبْدَ اللَّهِ بْنَ عَمْرٍو الأَنْصَارِيَّيْنِ، ثُمَّ السَّلَمِيَّيْنِ كَانَا قَدْ حَفَرَ السَّيْلُ قَبْرَهُمَا وَكَانَ قَبْرُهُمَا مِمَّا يَلِي السَّيْلَ وَكَانَا فِي قَبْرٍ وَاحِدٍ وَهُمَا مِمَّنِ اسْتُشْهِدَ يَوْمَ أُحُدٍ فَحُفِرَ عَنْهُمَا لِيُغَيَّرَا مِنْ مَكَانِهِمَا فَوُجِدَا لَمْ يَتَغَيَّرَا كَأَنَّهُمَا مَاتَا بِالأَمْسِ وَكَانَ أَحَدُهُمَا قَدْ جُرِحَ فَوَضَعَ يَدَهُ عَلَى جُرْحِهِ فَدُفِنَ وَهُوَ كَذَلِكَ فَأُمِيطَتْ يَدُهُ عَنْ جُرْحِهِ ثُمَّ أُرْسِلَتْ فَرَجَعَتْ كَمَا كَانَتْ وَكَانَ بَيْنَ أُحُدٍ وَبَيْنَ يَوْمَ حُفِرَ عَنْهُمَا سِتٌّ وَأَرْبَعُونَ سَنَةً ‏.‏ قَالَ مَالِكٌ لاَ بَأْسَ أَنْ يُدْفَنَ الرَّجُلاَنِ وَالثَّلاَثَةُ فِي قَبْرٍ وَاحِدٍ مِنْ ضَرُورَةٍ وَيُجْعَلَ الأَكْبَرُ مِمَّا يَلِي الْقِبْلَةَ ‏.‏\hadithno{1007}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik was asked whether, when an imam had accepted jizya from a people and they gave it, he thought that the land of one of them who surrendered belonged to him or whether his land and property belonged to the Muslims. Malik said, "That varies. As for the people of peace, if one of them surrenders, then he is entitled to his land and property. As for the people of force who use force, if one of them surrenders, his land and property belong to the Muslims because the people of force are overcome in their towns, and it becomes booty for the Muslims. As for the people of peace, their property and selves are protected so that they make peace for them. Only what they have made peace for is obliged of them." Yahya related to me from Malik from Abd ar-Rahman ibn Abi Sasaca that he had heard that Amr ibn al-Jamuh al-Ansari and Abdullah ibn Umar al-Ansari, both of the tribe of Banu Salami, had their grave uncovered by a flood. Their grave was part of what was left after the flood. They were in the same grave, and they were among those martyred at Uhud. They were dug up so that they might be moved. They were found unchanged. It was as if they had died only the day before. One of them had been wounded, and he had put his hand over his wound and had been buried like that. His hand was pulled away from his wound and released, and it returned to where it had been. It was forty-six years between Uhud and the day they were dug up. Malik said, "There is no harm in burying two or three men in the same grave due to necessity. The oldest one is put next to the qibla}}
\hadithdefcmd{malik}{1008}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ قَدِمَ عَلَى أَبِي بَكْرٍ الصِّدِّيقِ مَالٌ مِنَ الْبَحْرَيْنِ فَقَالَ مَنْ كَانَ لَهُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأْىٌ أَوْ عِدَةٌ فَلْيَأْتِنِي فَجَاءَهُ جَابِرُ بْنُ عَبْدِ اللَّهِ فَحَفَنَ لَهُ ثَلاَثَ حَفَنَاتٍ ‏.‏\hadithno{1008}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Rabia ibn Abi Abd ar-Rahman said, "Property was sent to Abu Bakr as-Siddiq from Bahrayn. He said, 'If someone had a promise or a pledge with the Messenger of Allah, may Allah bless him and grant him peace, let him come to me.' So Jabir ibn Abdullah came to him, and he gave him three times as much of it as would fill both hands}}
